pub enum InsertResult {
Inserted,
Replaced,
Skipped,
}Expand description
Result of a CS insert operation.
Variants
Inserted
Entry was stored.
Replaced
Entry replaced an existing entry for the same name.
Skipped
Entry was not stored (e.g., CS is disabled or at capacity with no eviction).