pub trait CsAdmissionPolicy:
Send
+ Sync
+ 'static {
// Required method
fn should_admit(&self, data: &Data) -> bool;
}Expand description
Policy that decides whether a Data packet should be admitted to the CS.
Implementations can inspect the decoded Data to make admission decisions based on FreshnessPeriod, ContentType, name prefix, etc.
Required Methods
Sourcefn should_admit(&self, data: &Data) -> bool
fn should_admit(&self, data: &Data) -> bool
Returns true if the Data should be cached.